@@ -1,7 +1,8 @@
 #
-# Copyright (c) 2019 by Delphix. All rights reserved.
+# Copyright (c) 2019, 2021 by Delphix. All rights reserved.
 #
 import dlpx.virtualization.api
+from dlpx.virtualization.common.util import to_str
 
 
 def get_virtualization_api_version():
@@ -9,4 +10,4 @@ def get_virtualization_api_version():
 
     :return: version string
     """
-    return dlpx.virtualization.api.__version__
+    return to_str(dlpx.virtualization.api.__version__)
